==> jupyterlite_javascript_kernel-0.3.0a1.tar.gz: jupyterlite_javascript_kernel-0.3.0a1/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.3.0a1

([Full Changelog](https://github.com/jupyterlite/javascript-kernel/compare/v0.3.0a0...24e8d7abb6bd51633233c5bbeac9d54a70e98047))

### Maintenance and upkeep improvements

- Fix shared packages [#8](https://github.com/jupyterlite/javascript-kernel/pull/8) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/javascript-kernel/graphs/contributors?from=2024-02-15&to=2024-02-16&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fjavascript-kernel+involves%3Ajtpio+updated%3A2024-02-15..2024-02-16&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.3.0a0

([Full Changelog](https://github.com/jupyterlite/javascript-kernel/compare/123a40c18f04b8aa22a86f2352366153e8ed1706...535e97b683a0fa127a936fbe07e05345794a3674))

### Maintenance and upkeep improvements

- Update pre-release replace logic [#7](https://github.com/jupyterlite/javascript-kernel/pull/7) ([@jtpio](https://github.com/jtpio))
- Better handle pre-releases [#6](https://github.com/jupyterlite/javascript-kernel/pull/6) ([@jtpio](https://github.com/jtpio))
- Add step to deploy to GitHub Pages [#4](https://github.com/jupyterlite/javascript-kernel/pull/4) ([@jtpio](https://github.com/jtpio))
- Updates and fixes [#1](https://github.com/jupyterlite/javascript-kernel/pull/1) ([@jtpio](https://github.com/jtpio))

### Documentation improvements

- README updates [#5](https://github.com/jupyterlite/javascript-kernel/pull/5) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/javascript-kernel/graphs/contributors?from=2024-02-15&to=2024-02-15&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fjavascript-kernel+involves%3Ajtpio+updated%3A2024-02-15..2024-02-15&type=Issues)

For previous versions, you can refer to the JupyterLite changelog, which is where this kernel used to be developed: https://jupyterlite.readthedocs.io/en/stable/changelog.html

==> jupyterlite_javascript_kernel-0.4.0a0.tar.gz: jupyterlite_javascript_kernel-0.4.0a0/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.4.0a0

([Full Changelog](https://github.com/jupyterlite/javascript-kernel/compare/@jupyterlite/javascript-kernel-extension@0.3.0...d557adf3cd01c6007b64e5a9be185d091c6531c3))

### Maintenance and upkeep improvements

- Update to JupyterLite 0.4.0 [#14](https://github.com/jupyterlite/javascript-kernel/pull/14) ([@jtpio](https://github.com/jtpio))
- Fix CI [#13](https://github.com/jupyterlite/javascript-kernel/pull/13) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/javascript-kernel/graphs/contributors?from=2024-03-26&to=2024-05-23&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fjavascript-kernel+involves%3Ajtpio+updated%3A2024-03-26..2024-05-23&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.3.0

([Full Changelog](https://github.com/jupyterlite/javascript-kernel/compare/@jupyterlite/javascript-kernel-extension@0.3.0-alpha.1...0ec2e58c1ec85fefbb35109e8414f5a2ba97de80))

### Maintenance and upkeep improvements

- Update releaser workflows [#11](https://github.com/jupyterlite/javascript-kernel/pull/11) ([@jtpio](https://github.com/jtpio))
- Update `@jupyterlite` packages [#10](https://github.com/jupyterlite/javascript-kernel/pull/10) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/javascript-kernel/graphs/contributors?from=2024-02-16&to=2024-03-26&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fjavascript-kernel+involves%3Ajtpio+updated%3A2024-02-16..2024-03-26&type=Issues)

## 0.3.0a1

([Full Changelog](https://github.com/jupyterlite/javascript-kernel/compare/v0.3.0a0...24e8d7abb6bd51633233c5bbeac9d54a70e98047))

### Maintenance and upkeep improvements

- Fix shared packages [#8](https://github.com/jupyterlite/javascript-kernel/pull/8) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/javascript-kernel/graphs/contributors?from=2024-02-15&to=2024-02-16&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fjavascript-kernel+involves%3Ajtpio+updated%3A2024-02-15..2024-02-16&type=Issues)

## 0.3.0a0

([Full Changelog](https://github.com/jupyterlite/javascript-kernel/compare/123a40c18f04b8aa22a86f2352366153e8ed1706...535e97b683a0fa127a936fbe07e05345794a3674))

### Maintenance and upkeep improvements

- Update pre-release replace logic [#7](https://github.com/jupyterlite/javascript-kernel/pull/7) ([@jtpio](https://github.com/jtpio))
- Better handle pre-releases [#6](https://github.com/jupyterlite/javascript-kernel/pull/6) ([@jtpio](https://github.com/jtpio))
- Add step to deploy to GitHub Pages [#4](https://github.com/jupyterlite/javascript-kernel/pull/4) ([@jtpio](https://github.com/jtpio))
- Updates and fixes [#1](https://github.com/jupyterlite/javascript-kernel/pull/1) ([@jtpio](https://github.com/jtpio))

### Documentation improvements

- README updates [#5](https://github.com/jupyterlite/javascript-kernel/pull/5) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/javascript-kernel/graphs/contributors?from=2024-02-15&to=2024-02-15&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fjavascript-kernel+involves%3Ajtpio+updated%3A2024-02-15..2024-02-15&type=Issues)

For previous versions, you can refer to the JupyterLite changelog, which is where this kernel used to be developed: https://jupyterlite.readthedocs.io/en/stable/changelog.html
